@@ -1,4 +1,4 @@
-# last modified 2017-01-18 by J. Fox
+# last modified 2019-01-21 by J. Fox
 
 # File (and Edit) menu dialogs
 
@@ -41,6 +41,7 @@ saveLogAs <- function() {
 					defaultextension="R",
 					initialfile="RCommander.R",
 					parent=CommanderWindow()))
+	logFile <- removeRedundantExtension(logFile)
 	if (logFile == "") return()
 	log <- tclvalue(tkget(LogWindow(), "1.0", "end"))
 	fileCon <- file(logFile, "w")
@@ -141,6 +142,7 @@ saveRmdAs <- function() {
         defaultextension="Rmd",
         initialfile="RCommanderMarkdown.Rmd",
         parent=CommanderWindow()))
+    RmdFile <- removeRedundantExtension(RmdFile)
     if (RmdFile == "") return()
     if (getRcmdr("Markdown.editor.open")){
         .rmd.window <- RmdWindow()
@@ -162,6 +164,7 @@ saveRnwAs <- function() {
                                       defaultextension="Rnw",
                                       initialfile="RCommanderKnitr.Rnw",
                                       parent=CommanderWindow()))
+    RnwFile <- removeRedundantExtension(RnwFile)
     if (RnwFile == "") return()
     if (getRcmdr("knitr.editor.open")){
         .rnw.window <- RnwWindow()
@@ -198,6 +201,7 @@ saveOutputAs <- function() {
 					defaultextension="txt",
 					initialfile="RCommander.txt",
 					parent=CommanderWindow()))
+	outputFile <- removeRedundantExtension(outputFile)
 	if (outputFile == "") return()
 	output <- tclvalue(tkget(OutputWindow(), "1.0", "end"))
 	fileCon <- file(outputFile, "w")
@@ -898,7 +902,7 @@ saveOptions <- function(){
     tkgrid(optionsXscroll, sticky="ew", columnspan=2)
     tkgrid(optionsFrame, sticky="news", padx=10, pady=0)
     tkgrid(buttonsFrame, sticky="ew")
-    dialogSuffix()
+    dialogSuffix(bindReturn=FALSE)
 }
 
 loadPackages <- function(){
